@@ -1,9 +1,8 @@
 /*
  * ffproxy (c) 2002, 2003 Niklas Olmes <niklas@noxa.de>
- *                                     <niklas.olmes@web.de>
  * http://faith.eu.org
  * 
- * $Id: alloc.c,v 1.5 2003/08/08 14:10:28 niklas Exp $
+ * $Id: alloc.c,v 2.1 2004/12/31 08:59:15 niklas Exp $
  * 
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free
@@ -21,7 +20,10 @@
  */
 
 #include <stdio.h>
-#include <stdlib.h>
+#include "configure.h"
+#ifdef HAVE_STDLIB_H
+# include <stdlib.h>
+#endif
 #include <string.h>
 
 #include "print.h"
