@@ -34,6 +34,9 @@ struct cfg {
 
 	int		kalive;
 
+	int		unr_con;
+	int		to_con;
+
 	int		nowarn;
 	int		first;
 };
