@@ -1,9 +1,8 @@
 /*
  * ffproxy (c) 2002, 2003 Niklas Olmes <niklas@noxa.de>
- *                                     <niklas.olmes@web.de>
  * http://faith.eu.org
  * 
- * $Id: file.c,v 1.4 2003/07/20 10:38:23 niklas Exp $
+ * $Id: file.c,v 2.1 2004/12/31 08:59:15 niklas Exp $
  * 
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free
@@ -21,7 +20,11 @@
  */
 
 #include <stdio.h>
-#include <fcntl.h>
+
+#include "configure.h"
+#ifdef HAVE_FCNTL_H
+# include <fcntl.h>
+#endif
 
 #include "print.h"
 #include "file.h"
