@@ -1,9 +1,8 @@
 /*
  * ffproxy (c) 2002, 2003 Niklas Olmes <niklas@noxa.de>
- *                                     <niklas.olmes@web.de>
  * http://faith.eu.org
  * 
- * $Id: regex.c,v 1.4 2003/07/20 10:38:23 niklas Exp $
+ * $Id: regex.c,v 2.1 2004/12/31 08:59:15 niklas Exp $
  * 
  * This program is free software; you can redistribute it and/or modify it under
  * the terms of the GNU General Public License as published by the Free
@@ -20,7 +19,10 @@
  * Mass Ave, Cambridge, MA 02139, USA.
  */
 
-#include <sys/types.h>
+#include "configure.h"
+#ifdef HAVE_SYS_TYPES_H
+# include <sys/types.h>
+#endif
 
 #include <regex.h>
 
